==> dcli-0.0.3.crate: dcli-0.0.3/changelog.md <==
<a name="0.0.3"></a>
## 0.0.3 i18n support and some features (2020-12-12)


#### Features

*   add i18n support ([3386712e](https://github.com/PrivateRookie/dcli/commit/3386712e7d8d087e66112584d67528bbeb11a20f))
*   use pool instead of connection ([08fafa42](https://github.com/PrivateRookie/dcli/commit/08fafa428bf3e371c657c9c3dc2977822461a6c5))
*   add read file feature ([72313957](https://github.com/PrivateRookie/dcli/commit/7231395787f5142551bd2d2ac04d51eb07905e28))
*   add commands ([024ef67d](https://github.com/PrivateRookie/dcli/commit/024ef67df4bdbc1b60b3ea121a83d99108af1ea4))



<a name="0.0.2"></a>
## 0.0.2 bug fixed (2020-12-12)


#### Bug Fixes

*   fix failed to create history file error ([44a05c96](https://github.com/PrivateRookie/dcli/commit/44a05c967525de2f820f6e00ac4eca3b0b7503db))
*   fix print output error ([b92f99fb](https://github.com/PrivateRookie/dcli/commit/b92f99fb40859ed3a43e6778ca9b5a7e17518aec))
*   fix print output error ([0e7d9e10](https://github.com/PrivateRookie/dcli/commit/0e7d9e1006855204c561e5eaeb4696cb0b7c057a))
*   use token base highlight instead of ast ([5d317482](https://github.com/PrivateRookie/dcli/commit/5d317482aa1578a5e6950cd07a439fb9e3e4058d))



<a name="0.0.1"></a>
## 0.0.1 init release (2020-12-12)


#### Features

*   add no dep shell interface ([6428b313](https://github.com/PrivateRookie/dcli/commit/6428b313130e4c0f77ee63a9427de3be33f1f1ab))
*   add shell ([7ac612ef](https://github.com/PrivateRookie/dcli/commit/7ac612ef2632f8e17dbc85503428142862868d4b))
*   add ssl connection support ([63d9c86c](https://github.com/PrivateRookie/dcli/commit/63d9c86c88122abd47c9122d8c12eaceb650fd6c))
*   add sqlx as connect adapter ([467cfb19](https://github.com/PrivateRookie/dcli/commit/467cfb19f9bb7b74d7d2d948e318dd9b60eddf36))
*   add exec command ([4f1174ac](https://github.com/PrivateRookie/dcli/commit/4f1174acdba7681c8eadc4d22cc83ec1bb15ed69))
*   format table & and add "add", "delete" command ([ac7307a5](https://github.com/PrivateRookie/dcli/commit/ac7307a57b2c4ac570f7ce69613fc784898300a1))
*   create config file when not found ([5dca8d5c](https://github.com/PrivateRookie/dcli/commit/5dca8d5c3c499727909605f053cb44fff7a74d19))
*   first runable version ([f4096982](https://github.com/PrivateRookie/dcli/commit/f4096982ee1908d941ea42873ba0ddfb83a37d28))

#### Bug Fixes

*   fix single column print bug ([14dd1d3e](https://github.com/PrivateRookie/dcli/commit/14dd1d3e89bdf26c4608b358e465691ff4b1226b))
*   fix mysql url construct error ([c8278b3d](https://github.com/PrivateRookie/dcli/commit/c8278b3d9cb1654d34f584af85b90d2106b510b6))

==> dcli-0.0.4.crate: dcli-0.0.4/changelog.md <==
<a name="0.0.4"></a>
## 0.0.4 support export data & bug fix (2020-12-17)


#### Features

*   support csv export ([06ffb29e](https://github.com/PrivateRookie/dcli/commit/06ffb29ed40395bb56e92408fa671eba5ae11cbe))
*   add export command ([e98b0c6f](https://github.com/PrivateRookie/dcli/commit/e98b0c6fa39dace54c9d746706b19e778676cb58))
*   add lang setting ([5834716b](https://github.com/PrivateRookie/dcli/commit/5834716b326931cca8c15d805c0be42149500712))

#### Bug Fixes

*   fix connect failed when database is empty ([725df2be](https://github.com/PrivateRookie/dcli/commit/725df2be3e75b5f1bb6cf6f456d54ff9af24af6f))
*   remove unuse deps ([a6aac0ed](https://github.com/PrivateRookie/dcli/commit/a6aac0edd5b9b85516ce717f961816c381def653))



<a name="0.0.3"></a>
## 0.0.3 i18n support and some features (2020-12-12)


#### Features

*   add i18n support ([3386712e](https://github.com/PrivateRookie/dcli/commit/3386712e7d8d087e66112584d67528bbeb11a20f))
*   use pool instead of connection ([08fafa42](https://github.com/PrivateRookie/dcli/commit/08fafa428bf3e371c657c9c3dc2977822461a6c5))
*   add read file feature ([72313957](https://github.com/PrivateRookie/dcli/commit/7231395787f5142551bd2d2ac04d51eb07905e28))
*   add commands ([024ef67d](https://github.com/PrivateRookie/dcli/commit/024ef67df4bdbc1b60b3ea121a83d99108af1ea4))



<a name="0.0.2"></a>
## 0.0.2 bug fixed (2020-12-12)


#### Bug Fixes

*   fix failed to create history file error ([44a05c96](https://github.com/PrivateRookie/dcli/commit/44a05c967525de2f820f6e00ac4eca3b0b7503db))
*   fix print output error ([b92f99fb](https://github.com/PrivateRookie/dcli/commit/b92f99fb40859ed3a43e6778ca9b5a7e17518aec))
*   fix print output error ([0e7d9e10](https://github.com/PrivateRookie/dcli/commit/0e7d9e1006855204c561e5eaeb4696cb0b7c057a))
*   use token base highlight instead of ast ([5d317482](https://github.com/PrivateRookie/dcli/commit/5d317482aa1578a5e6950cd07a439fb9e3e4058d))



<a name="0.0.1"></a>
## 0.0.1 init release (2020-12-12)


#### Features

*   add no dep shell interface ([6428b313](https://github.com/PrivateRookie/dcli/commit/6428b313130e4c0f77ee63a9427de3be33f1f1ab))
*   add shell ([7ac612ef](https://github.com/PrivateRookie/dcli/commit/7ac612ef2632f8e17dbc85503428142862868d4b))
*   add ssl connection support ([63d9c86c](https://github.com/PrivateRookie/dcli/commit/63d9c86c88122abd47c9122d8c12eaceb650fd6c))
*   add sqlx as connect adapter ([467cfb19](https://github.com/PrivateRookie/dcli/commit/467cfb19f9bb7b74d7d2d948e318dd9b60eddf36))
*   add exec command ([4f1174ac](https://github.com/PrivateRookie/dcli/commit/4f1174acdba7681c8eadc4d22cc83ec1bb15ed69))
*   format table & and add "add", "delete" command ([ac7307a5](https://github.com/PrivateRookie/dcli/commit/ac7307a57b2c4ac570f7ce69613fc784898300a1))
*   create config file when not found ([5dca8d5c](https://github.com/PrivateRookie/dcli/commit/5dca8d5c3c499727909605f053cb44fff7a74d19))
*   first runable version ([f4096982](https://github.com/PrivateRookie/dcli/commit/f4096982ee1908d941ea42873ba0ddfb83a37d28))

#### Bug Fixes

*   fix single column print bug ([14dd1d3e](https://github.com/PrivateRookie/dcli/commit/14dd1d3e89bdf26c4608b358e465691ff4b1226b))
*   fix mysql url construct error ([c8278b3d](https://github.com/PrivateRookie/dcli/commit/c8278b3d9cb1654d34f584af85b90d2106b510b6))
